==> react-dropdown-user-1.27.0.tgz: package/lib/index.js <==
/* eslint-disable react/prop-types */
import { useReducer } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { reducerActions, reducerInitialState, reducer } from './reducer';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var DropdownUser = function DropdownUser(_ref) {
  var _ref$expandOnMouseOve = _ref.expandOnMouseOver,
      expandOnMouseOver = _ref$expandOnMouseOve === void 0 ? false : _ref$expandOnMouseOve,
      _ref$linkFactory = _ref.linkFactory,
      Link = _ref$linkFactory === void 0 ? function (_ref2) {
    var href = _ref2.href,
        className = _ref2.className,
        children = _ref2.children,
        title = _ref2.title;
    return /*#__PURE__*/_jsx("a", {
      href: href,
      className: className,
      title: title,
      children: children
    });
  } : _ref$linkFactory,
      menu = _ref.menu,
      _ref$hasNotifications = _ref.hasNotifications,
      hasNotifications = _ref$hasNotifications === void 0 ? menu.some(function (_ref3) {
    var notifications = _ref3.notifications;
    return Boolean(notifications);
  }) : _ref$hasNotifications,
      user = _ref.user;

  var _useReducer = useReducer(reducer, reducerInitialState),
      state = _useReducer[0],
      dispatch = _useReducer[1];

  var toggleMenu = function toggleMenu() {
    return dispatch({
      type: reducerActions.TOGGLE_MENU
    });
  };

  var handleMouseOver = function handleMouseOver() {
    return expandOnMouseOver && dispatch({
      type: reducerActions.MOUSE_HOVER
    });
  };

  var handleMouseOut = function handleMouseOut() {
    return expandOnMouseOver && dispatch({
      type: reducerActions.MOUSE_OUT
    });
  };

  var handleClick = function handleClick() {
    return !expandOnMouseOver && toggleMenu();
  };

  var handleTouchStart = function handleTouchStart() {
    return expandOnMouseOver && collapseByTouch && toggleMenu();
  };

  var renderLink = function renderLink(_ref4, index) {
    var text = _ref4.text,
        url = _ref4.url,
        Icon = _ref4.icon,
        notifications = _ref4.notifications,
        highlight = _ref4.highlight;
    var linkClassName = cx('sui-DropdownUserMenu-listLink', {
      'sui-DropdownUserMenu-listLinkHighlight': highlight
    });
    return /*#__PURE__*/_jsx("li", {
      className: "sui-DropdownUserMenu-listItem",
      children: /*#__PURE__*/_jsxs(Link, {
        href: url,
        className: linkClassName,
        title: text,
        children: [/*#__PURE__*/_jsx("div", {
          className: "sui-DropdownUserMenu-listIcon",
          children: /*#__PURE__*/_jsx(Icon, {})
        }), /*#__PURE__*/_jsx("span", {
          className: "sui-DropdownUserMenu-listText",
          children: text
        }), hasNotifications && /*#__PURE__*/_jsx("span", {
          className: "sui-DropdownUserMenu-listNotification",
          children: notifications
        })]
      })
    }, text + "-" + index);
  };

  var expanded = state.expanded,
      collapseByTouch = state.collapseByTouch;
  var name = user.name,
      avatar = user.avatar;
  var wrapperClassName = cx('sui-DropdownUser', {
    'is-expanded': expanded,
    'has-notifications': hasNotifications
  });
  return /*#__PURE__*/_jsxs("div", {
    className: wrapperClassName,
    onMouseOver: handleMouseOver,
    onMouseOut: handleMouseOut,
    children: [/*#__PURE__*/_jsxs("div", {
      className: "sui-DropdownUser-button",
      onClick: handleClick,
      onTouchStart: handleTouchStart,
      children: [/*#__PURE__*/_jsx("div", {
        className: "sui-DropdownUser-buttonAvatarWrap",
        children: /*#__PURE__*/_jsx("img", {
          className: "sui-DropdownUser-buttonAvatar",
          src: avatar,
          alt: name + "-avatar"
        })
      }), /*#__PURE__*/_jsx("span", {
        className: "sui-DropdownUser-buttonText",
        children: name
      })]
    }), /*#__PURE__*/_jsx("div", {
      className: "sui-DropdownUserMenu-wrap",
      children: /*#__PURE__*/_jsx("div", {
        className: "sui-DropdownUserMenu",
        children: /*#__PURE__*/_jsx("ul", {
          className: "sui-DropdownUserMenu-list",
          children: menu.map(renderLink)
        })
      })
    })]
  });
};

DropdownUser.displayName = 'DropdownUser';
export default DropdownUser;

==> react-dropdown-user-1.28.0.tgz: package/lib/index.js <==
/* eslint-disable react/prop-types */
import { useReducer } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { reducerActions, reducerInitialState, reducer } from './reducer';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var DropdownUser = function DropdownUser(_ref) {
  var _ref$expandOnMouseOve = _ref.expandOnMouseOver,
      expandOnMouseOver = _ref$expandOnMouseOve === void 0 ? false : _ref$expandOnMouseOve,
      _ref$linkFactory = _ref.linkFactory,
      Link = _ref$linkFactory === void 0 ? function (_ref2) {
    var href = _ref2.href,
        className = _ref2.className,
        children = _ref2.children,
        title = _ref2.title;
    return /*#__PURE__*/_jsx("a", {
      href: href,
      className: className,
      title: title,
      children: children
    });
  } : _ref$linkFactory,
      menu = _ref.menu,
      _ref$hasNotifications = _ref.hasNotifications,
      hasNotifications = _ref$hasNotifications === void 0 ? menu.some(function (_ref3) {
    var notifications = _ref3.notifications;
    return Boolean(notifications);
  }) : _ref$hasNotifications,
      user = _ref.user;

  var _useReducer = useReducer(reducer, reducerInitialState),
      state = _useReducer[0],
      dispatch = _useReducer[1];

  var toggleMenu = function toggleMenu() {
    return dispatch({
      type: reducerActions.TOGGLE_MENU
    });
  };

  var handleMouseOver = function handleMouseOver() {
    return expandOnMouseOver && dispatch({
      type: reducerActions.MOUSE_HOVER
    });
  };

  var handleMouseOut = function handleMouseOut() {
    return expandOnMouseOver && dispatch({
      type: reducerActions.MOUSE_OUT
    });
  };

  var handleClick = function handleClick() {
    return !expandOnMouseOver && toggleMenu();
  };

  var handleTouchStart = function handleTouchStart() {
    return expandOnMouseOver && collapseByTouch && toggleMenu();
  };

  var renderLink = function renderLink(_ref4, index) {
    var text = _ref4.text,
        url = _ref4.url,
        Icon = _ref4.icon,
        notifications = _ref4.notifications,
        highlight = _ref4.highlight;
    var linkClassName = cx('sui-DropdownUserMenu-listLink', {
      'sui-DropdownUserMenu-listLinkHighlight': highlight
    });
    var hasLinkNotifications = Boolean(notifications);
    return /*#__PURE__*/_jsx("li", {
      className: "sui-DropdownUserMenu-listItem",
      children: /*#__PURE__*/_jsxs(Link, {
        href: url,
        className: linkClassName,
        title: text,
        children: [/*#__PURE__*/_jsx("div", {
          className: "sui-DropdownUserMenu-listIcon",
          children: /*#__PURE__*/_jsx(Icon, {})
        }), /*#__PURE__*/_jsx("span", {
          className: "sui-DropdownUserMenu-listText",
          children: text
        }), hasLinkNotifications && /*#__PURE__*/_jsx("span", {
          className: "sui-DropdownUserMenu-listNotification",
          children: notifications
        })]
      })
    }, text + "-" + index);
  };

  var expanded = state.expanded,
      collapseByTouch = state.collapseByTouch;
  var name = user.name,
      avatar = user.avatar;
  var wrapperClassName = cx('sui-DropdownUser', {
    'is-expanded': expanded,
    'has-notifications': hasNotifications
  });
  return /*#__PURE__*/_jsxs("div", {
    className: wrapperClassName,
    onMouseOver: handleMouseOver,
    onMouseOut: handleMouseOut,
    children: [/*#__PURE__*/_jsxs("div", {
      className: "sui-DropdownUser-button",
      onClick: handleClick,
      onTouchStart: handleTouchStart,
      children: [/*#__PURE__*/_jsx("div", {
        className: "sui-DropdownUser-buttonAvatarWrap",
        children: /*#__PURE__*/_jsx("img", {
          className: "sui-DropdownUser-buttonAvatar",
          src: avatar,
          alt: name + "-avatar"
        })
      }), /*#__PURE__*/_jsx("span", {
        className: "sui-DropdownUser-buttonText",
        children: name
      })]
    }), /*#__PURE__*/_jsx("div", {
      className: "sui-DropdownUserMenu-wrap",
      children: /*#__PURE__*/_jsx("div", {
        className: "sui-DropdownUserMenu",
        children: /*#__PURE__*/_jsx("ul", {
          className: "sui-DropdownUserMenu-list",
          children: menu.map(renderLink)
        })
      })
    })]
  });
};

DropdownUser.displayName = 'DropdownUser';
export default DropdownUser;
